@@ -1,6 +1,6 @@
 # %%
 import bnlearn as bn
-# print(bn.__version__)
+print(bn.__version__)
 # print(dir(bn))
 
 # # %%
@@ -181,10 +181,10 @@ bn.compare_networks(model, model_sl, pos=G['pos'])
 
 
 # Structure learning with black list
-model_wl = bn.structure_learning.fit(df, methodtype='hc', white_list=['asia','tub','bronc','xray','smoke'])
+model_wl = bn.structure_learning.fit(df, methodtype='ex', white_list=['asia','tub','bronc','xray','smoke'], bw_list_method='enforce')
 bn.plot(model_wl, pos=G['pos'])
 
-model_bl = bn.structure_learning.fit(df, methodtype='hc', black_list=['asia','tub'])
+model_bl = bn.structure_learning.fit(df, methodtype='hc', black_list=['asia','tub'], bw_list_method='enforce')
 bn.plot(model_bl, pos=G['pos'])
 
 # Compare models
